@@ -9,19 +9,20 @@ from mongoengine.fields import (Document, StringField, DateTimeField,
 class VelocityKPI(EmbeddedDocument):
     """The velocity KPI total and sub-totals."""
 
-    pr_size = FloatField(default=0.0)
-    pr_duration = FloatField(default=0.0)
-    pr_commit_count = FloatField(default=0.0)
+    size = FloatField(default=0.0)
+    duration = FloatField(default=0.0)
+    dev_time = FloatField(default=0.0)
+    commit_count = FloatField(default=0.0)
     commit_freq = FloatField(default=0.0)
 
 
 class DevelopmentKPI(EmbeddedDocument):
     """The investment KPI total and sub-totals."""
 
-    development_total = FloatField(default=0.0)
-    features = FloatField(default=0.0)
-    defects = FloatField(default=0.0)
+    feature = FloatField(default=0.0)
     debt = FloatField(default=0.0)
+    debug = FloatField(default=0.0)
+    defect = FloatField(default=0.0)
 
 
 class IssuesTotal(EmbeddedDocument):
@@ -182,6 +183,7 @@ class PrEvent(Document):
     total_length = IntField(default=0)
     comment_percent = FloatField()
     space_percent = FloatField()
+    char_per_lines = FloatField()
 
     # Linter fields
     linter_events = EmbeddedDocumentListField(LinterScanEvent)
