@@ -5,8 +5,6 @@ import os
 from mongoengine import connect
 from mongoengine.connection import disconnect
 from celery import Celery
-from pymemcache.client.base import Client
-from aioinflux import InfluxDBClient
 import motor.motor_asyncio
 import redis
 
@@ -18,7 +16,7 @@ class MongoSettings():
         self.mongo_pass = os.environ.get("MONGO_PASS")
         self.mongo_port = port if port is not None else os.environ.get("MONGO_PORT", 27017)
         self.mongo_host = host if host is not None else os.environ.get("MONGO_HOST", "host.docker.internal")
-        self.mongo_db = db_name if db_name is not None else os.environ.get("MONGO_DB", "topograph_db")
+        self.mongo_db = db_name if db_name is not None else os.environ.get("MONGO_DB", "topograph")
         self.host = f"mongodb://{self.mongo_host}:{self.mongo_port}"
         self.client = connect(self.mongo_db, host=self.host, port=self.mongo_port, connect=False)
 
@@ -52,48 +50,6 @@ class CelerySettings():
         ], force=True)
 
 
-class MemcacheClient:
-    ''' memcache client '''
-    client = None
-
-    def __new__(cls, host=None, port=None):
-        port = port if port else os.environ.get("MEMCACHE_PORT", 11211)
-        host = (
-            host if host else os.environ.get("MEMCACHE_HOST", "host.docker.internal")
-        )
-
-        client = Client(f"{host}:{port}")
-
-        return client
-
-
-class InfluxSettings:
-    ''' influxdb settings '''
-    client = None
-
-    def __init__(self, db_name=None, host=None, port=None):
-        self.user = os.environ.get("INFLUX_USER")
-        self.password = os.environ.get("INFLUX_PASS")
-        self.port = port if port else os.environ.get("INFLUX_PORT", 8086)
-        self.host = (
-            host if host else os.environ.get("INFLUX_HOST", "host.docker.internal")
-        )
-        self.db_name = (
-            db_name if db_name else os.environ.get("INFLUX_DB", "topograph_db")
-        )
-
-    def connect(self):
-        InfluxSettings.client = InfluxDBClient(
-            db=self.db_name,
-            host=self.host,
-            port=self.port,
-            username=self.user,
-            password=self.password,
-        )
-
-        return InfluxSettings.client
-
-
 class MotorClient:
     ''' motor client '''
     client = None
